@@ -26,6 +26,12 @@ _connection = threading.local()
 
 @locked
 def connection():
+    """Get a connection to the sqlite cache database.
+
+    Returns:
+        _connection.db
+    """
+
     global _connection
     if not hasattr(_connection, "db") or _connection.db is None:
         cache_dir = SETTINGS.get("cache-directory")
@@ -61,7 +67,7 @@ def connection():
 @locked
 def settings_changed():
     global _connection
-    if _connection.db is not None:
+    if hasattr(_connection, "db") and _connection.db is not None:
         _connection.db.close()
     _connection.db = None
 
@@ -71,7 +77,7 @@ SETTINGS.on_change(settings_changed)
 
 @locked
 def update_cache():
-
+    """Update cache size and size of each file in the database ."""
     with connection() as db:
         update = []
         for n in db.execute("SELECT path FROM cache WHERE size IS NULL"):
@@ -95,8 +101,23 @@ def update_cache():
             db.commit()
 
 
-@locked
 def register_cache_file(path, owner, args):
+    """Register a file in the cache
+
+    Parameters
+    ----------
+    path : str
+        Cache file to register
+    owner : str
+        Owner of the cache file (generally a source or a dataset)
+    args : dict
+        Dictionary to save with the file in the database, as json string.
+
+    Returns
+    -------
+    changes :
+        None or False if database does not need to be updated. TODO: clarify.
+    """
 
     db = connection()
 
@@ -151,6 +172,21 @@ def update(m, x):
 
 @locked
 def cache_file(owner: str, *args, extension: str = ".cache"):
+    """Creates a cache file in the climetlab cache-directory (defined in the :py:class:`Settings`).
+    Uses :py:func:`register_cache_file()`
+
+    Parameters
+    ----------
+    owner : str
+        The owner of the cache file is generally the name of the source that generated the cache.
+    extension : str, optional
+        Extension filename (such as ".nc" for NetCDF, etc.), by default ".cache"
+
+    Returns
+    -------
+    path : str
+        Full path to the cache file.
+    """
 
     m = hashlib.sha256()
     update(m, owner)
@@ -169,6 +205,8 @@ def cache_file(owner: str, *args, extension: str = ".cache"):
 
 
 class TmpFile:
+    """TmpFile to be used in a temporary file ."""
+
     def __init__(self, path):
         self.path = path
 
@@ -177,7 +215,8 @@ class TmpFile:
 
 
 @locked
-def temp_file(extension=".tmp"):
+def temp_file(extension=".tmp") -> TmpFile:
+
     fd, path = tempfile.mkstemp(suffix=extension)
     os.close(fd)
     return TmpFile(path)
