@@ -22,7 +22,12 @@ from nbconvert.preprocessors import ExecutePreprocessor
 
 EXAMPLES = os.path.join(os.path.dirname(os.path.dirname(__file__)), "docs", "examples")
 
-SKIP = ("11-icoads.ipynb", "09-weatherbench.ipynb")
+SKIP = (
+    "11-icoads.ipynb",
+    "09-weatherbench.ipynb",
+    "10-meteonet.ipynb",
+    "11-hurricane-database.ipynb",
+)
 
 MARS = (
     "04-source-mars.ipynb",
