@@ -23,3 +23,8 @@ def test_download():
 
 
 # TODO: test .tar, .zip, .tar.gz
+if __name__ == "__main__":
+    for k, f in sorted(globals().items()):
+        if k.startswith("test_") and callable(f):
+            print(k)
+            f()
